# --------------------------------------------------------------------
# --   *****************************
# --   *   Trenz Electronic GmbH   *
# --   *   Holzweg 19A             *
# --   *   32257 Bünde             *
# --   *   Germany                 *
# --   *****************************
# --------------------------------------------------------------------
# -- $Author :  Pohl, Zdenek $
# -- $Email :   zdenek.pohl@utia.cas.cz$
# --------------------------------------------------------------------
# -- Descriptio:
# --    TCL script is used to export sdsoc platform using xsct
# -- Change History:
# ------------------------------------------
# -- $Date: 2018/02/03 | $Author: Pohl, Zdenek
# -- - initial release
# -- - todo - support also Zynq platform and ZynqMP with libraries 
# ------------------------------------------
# -- $Date: 2018/04/16 | $Author: Pohl, Zdenek
# -- added support for libraries and headers included to platform  
# ------------------------------------------


#load parameters saved by export script to be used in sdsoc export process
source pfm_settings.tcl

# create hardware platform 
platform create -name ${design_name}\
         -desc "Trenz HDMI In/Out for TE0701 + TE0820 Zynq Ultrascale+ platform. Requires IMAGEON FMC extension board" \
         -hw "${tmp_path}/hw/${design_name}.dsa" \
         -out "${tmp_path}/PF" \
         -samples "${tmp_path}/samples" \
         -prebuilt


#search if library files for platform are provided
#we support one library file for standalone and one for linux targes
set standalone_libs [glob -nocomplain -directory ${tmp_path}/sw/${standalone_path}/lib *.a]
set linux_libs [glob -nocomplain -directory ${tmp_path}/sw/${linux_path}/lib *.a] 

 
     puts "Preparing standalone domain"
     sysconfig create -name standalone\
         -display-name "Standalone" \
         -desc {} \
         -boot "${tmp_path}/sw/${standalone_path}/boot" \
         -readme "${tmp_path}/sw/${standalone_path}/boot/generic.readme"

     boot -bif "${tmp_path}/sw/${standalone_path}/boot/standalone.bif"

#platform write

     domain create -name standalone \
       -proc psu_cortexa53_0 \
       -display-name "Standalone" \
       -desc {} \
       -os {standalone} \
       -runtime {cpp}

     domain config -prebuilt-data "${tmp_path}/prebuilt"

     app -lscript "${tmp_path}/sw/${standalone_path}/lscript.ld"

     if {[llength $standalone_libs] == 0} {
     } else {
	 library -lib-path "${standalone_libs}" -inc-path "${tmp_path}/sw/${standalone_path}/include"
     }



     sysconfig create -name {Linux}\
       -display-name {Linux} \
       -desc {} \
       -boot "${tmp_path}/sw/${linux_path}/boot" \
       -readme "${tmp_path}/sw/${linux_path}/boot/generic.readme" 

     boot -bif "${tmp_path}/sw/${linux_path}/boot/linux.bif"

     domain create -name {Linux} \
       -os {linux} \
       -proc {psu_cortexa53_0} \
       -display-name {Linux} \
       -desc {} \
       -runtime {cpp} \
       -image "${tmp_path}/sw/${linux_path}/image"

     domain config -prebuilt-data "${tmp_path}/prebuilt"
if {[llength $linux_libs] == 0} {
     } else {
	 library -lib-path "${linux_libs}" -inc-path "${tmp_path}/sw/${linux_path}/include"
     }

platform write

#generate platform
platform generate 


