/********************************************
 * UTIA AV CR, v.v.i
 * Signal Processing Department
 * Pod Vodarenskou vezi 4
 * 182 08 Prague
 * Czech Republic
 * web: http://zs.utia.cas.cz
 * contact: sp@utia.cz
 *
 * Filename: vdma.h
 * Date: 19.09.2016
 * Author: Lukas Kohout <kohoutl@utia.cas.cz>, Zdenek Pohl <xpohl@utia.cas.cz> *
 * Description:
 *   SW interface for Xilinx VDMA
 *
 * Changelog:
 *  aarch64 and linux compatibility
 *  increased MAX_LINE_BYTES_WIDTH
 *
 *
 ********************************************/

#ifndef __VDMA_H__
#define __VDMA_H__

#include "xil_types.h"
#include "xaxivdma.h"

//----------------------------------------------------------------
typedef struct {
  u32 x;
  u32 y;
} vdma_resolution_t;


typedef struct {
    // resolution = active video
    vdma_resolution_t res;

    // horizontal timing
    u32               hfp;
    u32               hsw;
    u32               hbp;
    u32               hsp;

    // vertical timing
    u32               vfp;
    u32               vsw;
    u32               vbp;
    u32               vsp;
} vdma_timing_t;


typedef struct {
    u32 x;
    u32 y;
} vdma_frame_offset_t;


struct struct_vdma_t {
    u16                 dev_id;
    UINTPTR             fb_base;
    u32                 fb_num;

    XAxiVdma            inst;
    XAxiVdma_DmaSetup   tx_setup;
    XAxiVdma_DmaSetup   rx_setup;

    u8                  tx_pix_bytes;
    u8                  rx_pix_bytes;

    vdma_resolution_t   storage_res;

    vdma_timing_t       tx_timing;
    vdma_timing_t       rx_timing;

    vdma_frame_offset_t tx_offset;
    vdma_frame_offset_t rx_offset;
};
typedef struct struct_vdma_t vdma_t;


#define MIN_LINE_BYTES_WIDTH  10  // 2^10 = 1024 ~ 320*3 aligned to kB
#define MAX_LINE_BYTES_WIDTH  14  // 2^13 = 8192 ~ 1920*3 aligned to kB
                                  // 2^14 = 16384 ~ 3840*3 aligned to kB

#define MIN_STORAGE_BYTES_WIDTH  18  // 2^18 = 256 kB ~ (320*2)*240 aligned to kB


//----------------------------------------------------------------
//int vdma_common_init( u16 dev_id, XAxiVdma *vdma_inst );
int vdma_rx_start( XAxiVdma *vdma_inst );
int vdma_tx_start( XAxiVdma *vdma_inst );
int vdma_rx_stop( XAxiVdma *vdma_inst );
int vdma_tx_stop( XAxiVdma *vdma_inst );

u32 vdma_align_stride( u32 line_width, u8 byte_cnt );
u32 vdma_align_storage_size( u32 line_cnt, u32 stride );

int vdma_rx_init( vdma_t *vdma );
int vdma_tx_init( vdma_t *vdma );
void vdma_clr_errors( vdma_t *vdma );
int vdma_check_err( vdma_t *vdma );
void vdma_print_registers( vdma_t *vdma );

#endif // __VDMA_H__

